@@ -4,6 +4,7 @@ from typing import IO, Any, Callable, Dict, List, Tuple, Union, TypeVar, Generic
 
 import requests
 
+from ...model import OapiHeader
 from ... import VERSION
 from ...config import Config
 from ...consts import *
@@ -134,12 +135,13 @@ class Request(Generic[T]):
         else:
             config.logger.debug("request http_path:%s, http_method:%s, access_token_type:%s, request body:%s" % (
                 self.http_path, self.http_method, self.access_token_type, self.request_body))
+            if self.content_type:
+                session.headers[CONTENT_TYPE] = self.content_type
+
             if self.response_stream_file:
-                session.headers[CONTENT_TYPE] = self.content_type
-                self.response = session.request(
-                    method, path, params=params, data=body, stream=True, timeout=self.timeout)
+                self.response = session.request(method, path, params=params, data=body, stream=True,
+                                                timeout=self.timeout)
             else:
-                session.headers[CONTENT_TYPE] = self.content_type
                 self.response = session.request(method, path, params=params, data=body, timeout=self.timeout)
 
         return self.response
@@ -151,8 +153,11 @@ class Request(Generic[T]):
             return
 
         body = self.request_body
+        if body:
+            self.content_type = DEFAULT_CONTENT_TYPE
+
         if body is None:
-            self.request_body = b''
+            self.request_body = None
         elif isinstance(body, str):
             self.request_body = body.encode('utf-8')
         elif isinstance(body, bytes):
@@ -163,7 +168,6 @@ class Request(Generic[T]):
             self.request_body = json.dumps(to_json(body))
         else:
             raise APIError(message='Unrecognized request_body type')
-        self.content_type = DEFAULT_CONTENT_TYPE
 
     def do(self, conf):
         # type: (Config) -> Response[T]
@@ -232,9 +236,8 @@ class Handlers(object):
         self.sign()
         req.do_request(self.config)
         ctx, resp = self.ctx, req.response
-        ctx.set_request_id(resp.headers.get(HTTP_HEADER_KEY_LOG_ID),
-                           resp.headers.get(HTTP_HEADER_KEY_REQUEST_ID))
-        ctx.set_http_status_code(resp.status_code)
+        ctx.set(HTTP_HEADER_KEY, OapiHeader(resp.headers))
+        ctx.set(HTTP_KEY_STATUS_CODE, resp.status_code)
 
         self.validate_response()
         self.parse_response()
@@ -559,5 +562,9 @@ def resolve_path(path, path_variables):  # type: (str, Dict[str, str]) -> str
     splitted = path.split('/')
     for i in range(len(splitted)):
         if splitted[i].startswith(':'):
-            splitted[i] = path_variables.get(splitted[i][1:], '')
+            k = splitted[i][1:]
+            v = path_variables.get(splitted[i][1:], '')
+            if v == '':
+                raise RuntimeError("http path:%s, param name `%s` not found value" % (path, k))
+            splitted[i] = v
     return '/'.join(splitted)
